<?php

require_once('../../config.php');


/**
 * Class to manage adobe connect server curl petitions and admin login
 * 
 * @abstract
 * @version       0.2
 * @author        David Monllaó <david.monllao@urv.cat>
 */
class ACConnection {

    var $blockconfig;
    
    /**
     * ACConnection constructor
     * 
     * Before do something we must ensure that the block is set
     * 
     * @return void
     */
    function ACConnection() {
        
        $this->blockconfig = get_config('blocks/adobeconnect');
        
        $expectedvars = array('host', 'user', 'pwd', 'https', 'folderid');
        
        if (empty($this->blockconfig)) {
            print_error('errorconfigureblock', 'block_adobeconnect');
        }
        
        foreach ($expectedvars as $var) {
            if (!isset($this->blockconfig->$var)) {
                print_error('errorconfigureblock', 'block_adobeconnect');
            }
        }
        
        // Little check
        $this->blockconfig->host = rtrim($this->blockconfig->host, '/');
    }
    
    
    /**
     * Sends a petition to the requested url
     *
     * @param     string      $url       Requested url
     * @param     object      $args      Url arguments 
     * @param     boolean     $headers   Headers as response?
     * @return    string                 Remote host response
     */
    function curlPetition($args, $headers=false) {
        
        if (empty($args->action) || $args->action == '') {
            return false;
        }
        
        if (empty($this->blockconfig->https) || $this->blockconfig->https == '0') {
            $url = 'http://';
        } else {
            $url = 'https://';
        }
        $url .= $this->blockconfig->host.'/api/xml?action='.$args->action;
        
        foreach ($args as $arg => $value) {
            $url .= '&'.$arg.'='.$value;
        }
                
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_HEADER, $headers);
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        $response = curl_exec($ch);
        
        // We must ensure the content type returned as well as the http code
        $info = curl_getinfo($ch);
        if (empty($info['content_type']) ||
            $info['content_type'] != 'text/xml' || 
            $info['http_code'] != 200) {
                
                print_error('errorwrongresponse', 'block_adobeconnect');
        }
        
        if (strstr($response, 'status') == false || strstr($response, 'code') == false) {
            print_error('errorwrongresponse', 'block_adobeconnect');
        }
        
        return $response;
    }
    
    
    /**
     * Gets a validated session cookie of an adobe connect admin
     *
     * @return    string       Admin role validated session
     */
    function getAdminSession() {

        // Getting a session
        $commoninfo->action = 'common-info';
        
        if (!$data = simplexml_load_string($this->curlPetition($commoninfo))) {
            return false;
        }
        
        if (empty($data->common->cookie)) {
            return false;
        }
        
        $sessionid = $data->common->cookie;
        
        // Auth session cookie
        $auth->action = 'login';
        $auth->password = $this->blockconfig->pwd;
        $auth->login = $this->blockconfig->user;
        $auth->session = $sessionid;
                
        if (!$data = simplexml_load_string($this->curlPetition($auth))) {
            return false;
        }
        
        if ($data->status['code'] != 'ok') {
            return false;
        }
        
        return $sessionid;
    }


    /**
     * Closes an opened session
     * 
     * @param     string         $sessionid     Session to close
     */
    function closeSession($sessionid) {

        $logout->action = 'logout';
        $logout->session = $sessionid;
        
        $this->curlPetition($logout);
    }


    /**
     * Encodes a string to hexadecimal chars
     *
     * @param      string       $string     String to encode
     * @return     string                   Encoded string
     */
    function stringToHex($string) {
    	
        $ascii = '';
        for ($i = 0; $i < strlen($string); $i++) {
            $ascii .= '%'.dechex(ord($string[$i]));
        }
      
        return $ascii;
    }

}
?>
