<?php

require_once('./ACConnection.php');


class ACRoom extends ACConnection {


    /**
     * Check if there is a room for $courseid
     *
     * @param      string      $sessionid        Admin session id
     * @param      integer     $courseid         Moodle course id and room name
     * @return     object                        Room data
     */
    function checkRoom($sessionid, $courseid) {
  
        $room->action = 'sco-expanded-contents';
        $room->{'filter-type'} = 'meeting';
        $room->{'filter-name'} = $courseid;
        $room->{'sco-id'} = $this->blockconfig->folderid;
        $room->session = $sessionid;
        
        $data = simplexml_load_string($this->curlPetition($room));
        
        if ($data->status['code'] != 'ok' || empty($data->{'expanded-scos'})) {        
            return false;
        }
        
        $roomdata->scoid = $data->{'expanded-scos'}->sco['sco-id'];
        $roomdata->url = rtrim($data->{'expanded-scos'}->sco->{'url-path'}, '/');
        
        return $roomdata;
    }
    
    
    /**
     * Creates a new room
     * 
     * @param        string       $sessionid       Authenticated admin session
     * @param        integer      $courseid        Adobe Connect room name
     * @return       object                        Created room data
     */
    function createRoom($sessionid, $courseid) {
  
        $newroom->action = 'sco-update';
        $newroom->name = $courseid;
        $newroom->type = 'meeting';
        $newroom->{'folder-id'} = $this->blockconfig->folderid;
        $newroom->session = $sessionid;
        
        $data = simplexml_load_string($this->curlPetition($newroom));
        
        if ($data->status['code'] != 'ok' || empty($data->sco)) {        
            return false;
        }
        
        $room->scoid = $data->sco['sco-id'];
        $room->url = rtrim($data->sco->{'url-path'}, '/');
        
        return $room;
    }


    /**
     * Assigns a moodle user to an adobe connect room
     * 
     * Previous code must check that $username is an adobe connect valid user 
     * and $courseid is an existing adobe connect room
     * 
     * @param       string        $principalid      Adobe Connect user id
     * @param       integer       $scoid            Adobe Connect room id
     * @param       string        $role             Adobe Connect role to assign
     * @param       string        $sessionid        Adobe Connect admin session id
     * @return      boolean                         Success?
     */
    function assignUser($principalid, $scoid, $role, $sessionid) {

        global $CFG;
        
        $assignment->action = 'permissions-update';
        $assignment->{'permission-id'} = $role;
        $assignment->{'acl-id'} = $scoid;
        $assignment->{'principal-id'} = $principalid;
        $assignment->session = $sessionid;
        
        $data = simplexml_load_string($this->curlPetition($assignment));
        if ($data->status['code'] != 'ok') {
            return false;
        }
        
        return true;
    }

}

?>
