<?php

require_once('./ACConnection.php');


class ACUser extends ACConnection {


    /**
     * User authentication in Adobe Connect
     *
     * @param      string        $username         Username to authenticate
     * @return     string                          $username Adobe Connect session id
     */
    function getUserSession($username) {
        
        $commoninfo->action = 'common-info';
        
        if (!$data = simplexml_load_string($this->curlPetition($commoninfo))) {
            return false;
        }
        $sessionid = $data->common->cookie;
        
        $usersession->action = 'login';
        $usersession->login = $username;
        $usersession->password = md5($username);
        $usersession->session = $sessionid;
        
        if (!$data = simplexml_load_string($this->curlPetition($usersession))) {
            return false;
        }
        
        if ($data->status['code'] != 'ok') {
            return false;
        }
        
        return $sessionid;
    }


    /**
     * Check if an user exists in Adobe Connect
     * 
     * @param        string        $sessionid      Adobe Connect Admin sessionid
     * @param        string        $username       Username to find
     * @return       integer                       Adobe Connect user id
     */
    function checkUser($sessionid, $username) {
          
        $user->action = 'principal-list';
        $user->{'filter-login'} = $username;
        $user->session = $sessionid;
        
        $data = simplexml_load_string($this->curlPetition($user));
        if ($data->status['code'] != 'ok') {
            return false;
        }
        
        if (!$principalid = $data->{'principal-list'}->principal['principal-id']) {
            return false;
        }
        
        return $principalid;
    }
    
    
    /**
     * Creates an user in Adobe Connect
     * 
     * @param       string        $sessionid       Admin Adobe Connect authenticated session
     * @param       string        $username        
     * @param       string        $firstname
     * @param       string        $lastname
     * @return      integer                        Adobe Connect user id
     */
    function createUser($sessionid, $username, $firstname, $lastname) {
        
        $maxfieldchars = 30;
        
        // Ensure that the user doesn't exists yet
        if ($principalid = $this->checkUser($sessionid, $username)) {
            return $principalid;
        }
        
        if (empty($firstname) || rtrim($firstname) == '') {
            return false;
        }
        if (empty($lastname) || rtrim($lastname) == '') {
            return false;
        }
        if (empty($username) || rtrim($username) == '') {
            return false;
        }
        
        // $maxfieldchars is the Adobe Connect limit 
        $firstname = substr($firstname, 0, $maxfieldchars);
        $lastname = substr($lastname, 0, $maxfieldchars);
        
        $newuser->action = 'principal-update';
        $newuser->type = 'user';
        $newuser->{'has-children'} = '0';
        $newuser->login = $username;
        $newuser->password = md5($username);
        $newuser->email = $username;
        $newuser->{'first-name'} = $this->stringToHex($firstname);
        $newuser->{'last-name'} = $this->stringToHex($lastname);
        $newuser->session = $sessionid;
        
        if (!$data = simplexml_load_string($this->curlPetition($newuser))) {
            return false;
        }
        
        if ($data->status['code'] != 'ok') {
            return false;
        }
        
        if (!$principalid = $data->principal['principal-id']) {
            return false;
        }
        
        return $principalid;
    }
    
    
    /**
     * Returns a valid username format string for Adobe Connect
     *
     * @param        string      $emailstring       Original user email
     * @return       string                         Valid email
     */
    function getUsernameString($emailstring) {
            
        // Adobe Connect username and email limited to 60 chars
        $maxusernamechars = 59;
        
        if (strlen($emailstring) <= $maxusernamechars) {
            return $emailstring;
        }
        
        $emailarray = explode('@', $emailstring);
        
        // Respecting the domain string
        $domainchars = strlen($emailarray[1]) + 1;
        $avaiableusernamechars = $maxusernamechars - $domainchars;
        
        $emailarray[0] = substr($emailarray[0], 0, $avaiableusernamechars);
        
        return implode('@', $emailarray);
    }

}

?>
