<?php

/**
 * Main script to open an Adobe Connect session
 * 
 * Requires a valid adobe connect administrator  
 * account to create rooms, users assign users
 * 
 * @uses      Adobe Connect Server
 * @version   0.2
 * @todo      Lower number of petitions when user and room already exists
 * @author    David Monllaó <david.monllao@urv.cat>
 */


require_once('../../config.php');

require_once('./ACUser.php');
require_once('./ACRoom.php');

$courseid = required_param('courseid', PARAM_INT);
$context = get_context_instance(CONTEXT_COURSE, $courseid);

require_login($courseid);

// Check capability
if (!has_capability('block/adobeconnect:viewrole', $context)) {
    print_error('erroraccessdenied', 'block_adobeconnect');
}

// Only teacher and student role allowed
if (has_capability('block/adobeconnect:hostrole', $context)) {
    $role = 'host';
} else {
    $role = 'view';
}


// Getting admin session
$acuser = new ACUser();
$adminsessionid = $acuser->getAdminSession();
if (!$adminsessionid) {
    print_error('errornoadminsess', 'block_adobeconnect');
}

// Getting room data (admin session)
$acroom = new ACRoom();
$roomdata = $acroom->checkRoom($adminsessionid, $courseid);
if (empty($roomdata) || !$roomdata->scoid) {

    // If there is no room we must create it
    $roomdata = $acroom->createRoom($adminsessionid, $courseid);
    if (!$roomdata) {
        print_error('errorcantcreateroom', 'block_adobeconnect', '', $courseid);
    }
}


// We must ensure that the Adobe Connect username doesn't "overflow" the Adobe Connect chars limitation
$adobeconnectusername = $acuser->getUsernameString($USER->email);

// Getting the adobe connect user of $USER and his/her session
$principalid = $acuser->checkUser($adminsessionid, $adobeconnectusername);
if (!$principalid) {

    $principalid = $acuser->createUser($adminsessionid, $adobeconnectusername, $USER->firstname, $USER->lastname);
    if (!$principalid) {
        print_error('errorcantcreateuser', 'block_adobeconnect', '', $USER->firstname.' '.$USER->lastname);
    }
    
}

// Getting the adobe connect user of $USER and his/her session
$usersession = $acuser->getUserSession($adobeconnectusername);
if (!$usersession) {
    print_error('errornologin', 'block_adobeconnect');
}


// We assign only if user is no yet assigned
if (!$acroom->assignUser($principalid, $roomdata->scoid, $role, $adminsessionid)) {
    print_error('errornoassign', 'block_adobeconnect', '', $courseid);
}

// Closing admin session
$acuser->closeSession($adminsessionid);


add_to_log($courseid, 'adobeconnect', 'access');

$host = rtrim(get_config('blocks/adobeconnect', 'host'),'/');
$url = 'http://'.$host.$roomdata->url.'?session='.$usersession;
redirect($url);

?>
